boofun.analysis.canalization
==============================

.. automodule:: boofun.analysis.canalization


   .. rubric:: Functions

   .. autosummary::

      edge_effectiveness
      effective_degree
      get_canalizing_depth
      get_canalizing_variables
      get_essential_variables
      get_input_types
      get_symmetry_groups
      input_redundancy
      is_canalizing
      is_k_canalizing
      is_nested_canalizing

   .. rubric:: Classes

   .. autosummary::

      CanalizationAnalyzer
